-- Table features:
-- Unlogged, identity primary key, Autovacuum disabled
CREATE UNLOGGED TABLE cache_entries (
  id BIGINT GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
  content TEXT,
  created_at TIMESTAMPTZ
) WITH (autovacuum_enabled = FALSE);

-- Function returns trigger, using PLPGSQL, TX control
CREATE FUNCTION cache_entries_delete_old()
RETURNS TRIGGER LANGUAGE PLPGSQL AS $$
BEGIN
  DELETE FROM cache_entries
  WHERE created_at < NOW() - INTERVAL '5 minutes';
  RETURN NEW;
END;
$$;

-- Trigger
CREATE TRIGGER cache_entries_delete_old_trigger
AFTER INSERT ON cache_entries
EXECUTE PROCEDURE cache_entries_delete_old();

-- Current time, should not be deleted
INSERT INTO cache_entries (content, created_at)
VALUES ('some:cache:value:123', NOW());

-- Insert a value from 4 minutes ago, run `SELECT COUNT(*)` on cache_entries
-- confirm it's 2
INSERT INTO cache_entries (content, created_at)
VALUES ('some:cache:value:456', NOW() - INTERVAL '4  minutes');

SELECT * FROM cache_entries;

-- Wait 1 minute, try inserting a new row:
-- Confirm the count is 2, and "some:cache:value:456" was removed
INSERT INTO cache_entries (content, created_at)
VALUES ('some:cache:value:789', NOW());
